@@ -716,12 +716,15 @@ def pretraining_numpy(arr, batch_size, shuffle=False, max_obs=100,
         Tensorflow Dataset: Iterator withg preprocessed batches
     """
 
-    
+    max_len_arr = max(list(map(lambda x:x.shape[0], arr)))
+    padded_lcs = list(map(lambda x:np.pad(x, ((0,max_len_arr-x.shape[0]), (0,0))), arr))
+    padded_lcs = np.array(padded_lcs)
+
     fn = adjust_fn(_parse_pt_numpy, msk_frac, rnd_frac, same_frac, max_obs)
 
 
 
-    dataset = tf.data.Dataset.from_tensor_slices(arr)
+    dataset = tf.data.Dataset.from_tensor_slices(padded_lcs)
     if shuffle:
         print('[INFO] Shuffling')
         dataset = dataset.shuffle(1000)
@@ -730,4 +733,18 @@ def pretraining_numpy(arr, batch_size, shuffle=False, max_obs=100,
     dataset = dataset.cache()
     dataset = dataset.padded_batch(batch_size)
     dataset = dataset.prefetch(buffer_size=tf.data.AUTOTUNE)
-    return dataset
\ No newline at end of file
+    return dataset
+
+
+def pretraining_data(data, batch_size, shuffle=False, max_obs=100,
+                        msk_frac=0.2, rnd_frac=0.1, same_frac=0.1):
+    if isinstance(data, list):
+        data =  pretraining_numpy(data, batch_size, shuffle=shuffle, max_obs=max_obs,
+                        msk_frac=msk_frac, rnd_frac=rnd_frac, same_frac=same_frac)
+        return data
+    elif isinstance(data, str):
+        data =  pretraining_records_v2(data, batch_size, shuffle=shuffle, max_obs=max_obs,
+                        msk_frac=msk_frac, rnd_frac=rnd_frac, same_frac=same_frac)
+        return data
+    else:
+        raise TypeError("pretraining_data only accepts either a list of numpy arrays containing lightcurves or a path to the record file(str)")
\ No newline at end of file
